@@ -1,6 +1,8 @@
 """Promises, promises, promises"""
 from __future__ import absolute_import, unicode_literals
 
+import re
+
 from collections import namedtuple
 
 from .abstract import Thenable
@@ -11,20 +13,27 @@ from .funtools import (
     ppartial, preplace, starpromise, transform, wrap,
 )
 
-version_info_t = namedtuple(
-    'version_info_t', ('major', 'minor', 'micro', 'releaselevel', 'serial'),
-)
 
-VERSION = version_info = version_info_t(1, 1, 1, '', '')
-
-__version__ = '{0.major}.{0.minor}.{0.micro}{0.releaselevel}'.format(VERSION)
+__version__ = '1.1.2'
 __author__ = 'Ask Solem'
 __contact__ = 'ask@celeryproject.org'
-__homepage__ = 'http://github.com/celery/vine',
+__homepage__ = 'http://github.com/celery/vine'
 __docformat__ = 'restructuredtext'
 
 # -eof meta-
 
+version_info_t = namedtuple('version_info_t', (
+    'major', 'minor', 'micro', 'releaselevel', 'serial',
+))
+# bump version can only search for {current_version}
+# so we have to parse the version here.
+_temp = re.match(
+    r'(\d+)\.(\d+).(\d+)(.+)?', __version__).groups()
+VERSION = version_info = version_info_t(
+    int(_temp[0]), int(_temp[1]), int(_temp[2]), _temp[3] or '', '')
+del(_temp)
+del(re)
+
 __all__ = [
     'Thenable', 'promise', 'barrier',
     'maybe_promise', 'ensure_promise',
